import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AntiSpywareProfile("example", {});
 * ```
 */
export declare class AntiSpywareProfile extends pulumi.CustomResource {
    /**
     * Get an existing AntiSpywareProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AntiSpywareProfileState, opts?: pulumi.CustomResourceOptions): AntiSpywareProfile;
    /**
     * Returns true if the given object is an instance of AntiSpywareProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AntiSpywareProfile;
    /**
     * The CloudInlineAnalysis param. Default: `false`.
     */
    readonly cloudInlineAnalysis: pulumi.Output<boolean>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The InlineExceptionEdlUrls param.
     */
    readonly inlineExceptionEdlUrls: pulumi.Output<string[] | undefined>;
    /**
     * The InlineExceptionIpAddresses param.
     */
    readonly inlineExceptionIpAddresses: pulumi.Output<string[] | undefined>;
    /**
     * The MicaEngineSpywareEnabledList param.
     */
    readonly micaEngineSpywareEnabledLists: pulumi.Output<outputs.AntiSpywareProfileMicaEngineSpywareEnabledList[] | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Rules param.
     */
    readonly rules: pulumi.Output<outputs.AntiSpywareProfileRule[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The ThreatExceptions param.
     */
    readonly threatExceptions: pulumi.Output<outputs.AntiSpywareProfileThreatException[] | undefined>;
    /**
     * Create a AntiSpywareProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AntiSpywareProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AntiSpywareProfile resources.
 */
export interface AntiSpywareProfileState {
    /**
     * The CloudInlineAnalysis param. Default: `false`.
     */
    cloudInlineAnalysis?: pulumi.Input<boolean>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The InlineExceptionEdlUrls param.
     */
    inlineExceptionEdlUrls?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The InlineExceptionIpAddresses param.
     */
    inlineExceptionIpAddresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The MicaEngineSpywareEnabledList param.
     */
    micaEngineSpywareEnabledLists?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileMicaEngineSpywareEnabledList>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileThreatException>[]>;
}
/**
 * The set of arguments for constructing a AntiSpywareProfile resource.
 */
export interface AntiSpywareProfileArgs {
    /**
     * The CloudInlineAnalysis param. Default: `false`.
     */
    cloudInlineAnalysis?: pulumi.Input<boolean>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The InlineExceptionEdlUrls param.
     */
    inlineExceptionEdlUrls?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The InlineExceptionIpAddresses param.
     */
    inlineExceptionIpAddresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The MicaEngineSpywareEnabledList param.
     */
    micaEngineSpywareEnabledLists?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileMicaEngineSpywareEnabledList>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileThreatException>[]>;
}
