import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AuthenticationSequence("example", {});
 * ```
 */
export declare class AuthenticationSequence extends pulumi.CustomResource {
    /**
     * Get an existing AuthenticationSequence resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthenticationSequenceState, opts?: pulumi.CustomResourceOptions): AuthenticationSequence;
    /**
     * Returns true if the given object is an instance of AuthenticationSequence.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthenticationSequence;
    /**
     * The AuthenticationProfiles param.
     */
    readonly authenticationProfiles: pulumi.Output<string[] | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The UseDomainFindProfile param. Default: `true`.
     */
    readonly useDomainFindProfile: pulumi.Output<boolean>;
    /**
     * Create a AuthenticationSequence resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AuthenticationSequenceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthenticationSequence resources.
 */
export interface AuthenticationSequenceState {
    /**
     * The AuthenticationProfiles param.
     */
    authenticationProfiles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The UseDomainFindProfile param. Default: `true`.
     */
    useDomainFindProfile?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a AuthenticationSequence resource.
 */
export interface AuthenticationSequenceArgs {
    /**
     * The AuthenticationProfiles param.
     */
    authenticationProfiles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The UseDomainFindProfile param. Default: `true`.
     */
    useDomainFindProfile?: pulumi.Input<boolean>;
}
