import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.CertificateProfile("example", {});
 * ```
 */
export declare class CertificateProfile extends pulumi.CustomResource {
    /**
     * Get an existing CertificateProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CertificateProfileState, opts?: pulumi.CustomResourceOptions): CertificateProfile;
    /**
     * Returns true if the given object is an instance of CertificateProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CertificateProfile;
    /**
     * The BlockExpiredCert param.
     */
    readonly blockExpiredCert: pulumi.Output<boolean | undefined>;
    /**
     * The BlockTimeoutCert param.
     */
    readonly blockTimeoutCert: pulumi.Output<boolean | undefined>;
    /**
     * The BlockUnauthenticatedCert param.
     */
    readonly blockUnauthenticatedCert: pulumi.Output<boolean | undefined>;
    /**
     * The BlockUnknownCert param.
     */
    readonly blockUnknownCert: pulumi.Output<boolean | undefined>;
    /**
     * The CaCertificates param.
     */
    readonly caCertificates: pulumi.Output<outputs.CertificateProfileCaCertificate[]>;
    /**
     * The CertStatusTimeout param.
     */
    readonly certStatusTimeout: pulumi.Output<string | undefined>;
    /**
     * The CrlReceiveTimeout param.
     */
    readonly crlReceiveTimeout: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Domain param.
     */
    readonly domain: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The OcspReceiveTimeout param.
     */
    readonly ocspReceiveTimeout: pulumi.Output<string | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The UseCrl param.
     */
    readonly useCrl: pulumi.Output<boolean | undefined>;
    /**
     * The UseOcsp param.
     */
    readonly useOcsp: pulumi.Output<boolean | undefined>;
    /**
     * The UsernameField param.
     */
    readonly usernameField: pulumi.Output<outputs.CertificateProfileUsernameField | undefined>;
    /**
     * Create a CertificateProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CertificateProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CertificateProfile resources.
 */
export interface CertificateProfileState {
    /**
     * The BlockExpiredCert param.
     */
    blockExpiredCert?: pulumi.Input<boolean>;
    /**
     * The BlockTimeoutCert param.
     */
    blockTimeoutCert?: pulumi.Input<boolean>;
    /**
     * The BlockUnauthenticatedCert param.
     */
    blockUnauthenticatedCert?: pulumi.Input<boolean>;
    /**
     * The BlockUnknownCert param.
     */
    blockUnknownCert?: pulumi.Input<boolean>;
    /**
     * The CaCertificates param.
     */
    caCertificates?: pulumi.Input<pulumi.Input<inputs.CertificateProfileCaCertificate>[]>;
    /**
     * The CertStatusTimeout param.
     */
    certStatusTimeout?: pulumi.Input<string>;
    /**
     * The CrlReceiveTimeout param.
     */
    crlReceiveTimeout?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Domain param.
     */
    domain?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The OcspReceiveTimeout param.
     */
    ocspReceiveTimeout?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The UseCrl param.
     */
    useCrl?: pulumi.Input<boolean>;
    /**
     * The UseOcsp param.
     */
    useOcsp?: pulumi.Input<boolean>;
    /**
     * The UsernameField param.
     */
    usernameField?: pulumi.Input<inputs.CertificateProfileUsernameField>;
}
/**
 * The set of arguments for constructing a CertificateProfile resource.
 */
export interface CertificateProfileArgs {
    /**
     * The BlockExpiredCert param.
     */
    blockExpiredCert?: pulumi.Input<boolean>;
    /**
     * The BlockTimeoutCert param.
     */
    blockTimeoutCert?: pulumi.Input<boolean>;
    /**
     * The BlockUnauthenticatedCert param.
     */
    blockUnauthenticatedCert?: pulumi.Input<boolean>;
    /**
     * The BlockUnknownCert param.
     */
    blockUnknownCert?: pulumi.Input<boolean>;
    /**
     * The CaCertificates param.
     */
    caCertificates: pulumi.Input<pulumi.Input<inputs.CertificateProfileCaCertificate>[]>;
    /**
     * The CertStatusTimeout param.
     */
    certStatusTimeout?: pulumi.Input<string>;
    /**
     * The CrlReceiveTimeout param.
     */
    crlReceiveTimeout?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Domain param.
     */
    domain?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The OcspReceiveTimeout param.
     */
    ocspReceiveTimeout?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The UseCrl param.
     */
    useCrl?: pulumi.Input<boolean>;
    /**
     * The UseOcsp param.
     */
    useOcsp?: pulumi.Input<boolean>;
    /**
     * The UsernameField param.
     */
    usernameField?: pulumi.Input<inputs.CertificateProfileUsernameField>;
}
