import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.DecryptionProfile("example", {});
 * ```
 */
export declare class DecryptionProfile extends pulumi.CustomResource {
    /**
     * Get an existing DecryptionProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DecryptionProfileState, opts?: pulumi.CustomResourceOptions): DecryptionProfile;
    /**
     * Returns true if the given object is an instance of DecryptionProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DecryptionProfile;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * Must start with alphanumeric char and should contain only alphanemeric, underscore, hyphen, dot or space. String validation regex: `^[A-Za-z0-9]{1}[A-Za-z0-9_\-\.\s]{0,}$`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The SslForwardProxy param.
     */
    readonly sslForwardProxy: pulumi.Output<outputs.DecryptionProfileSslForwardProxy | undefined>;
    /**
     * The SslInboundProxy param.
     */
    readonly sslInboundProxy: pulumi.Output<outputs.DecryptionProfileSslInboundProxy | undefined>;
    /**
     * The SslNoProxy param.
     */
    readonly sslNoProxy: pulumi.Output<outputs.DecryptionProfileSslNoProxy | undefined>;
    /**
     * The SslProtocolSettings param.
     */
    readonly sslProtocolSettings: pulumi.Output<outputs.DecryptionProfileSslProtocolSettings | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a DecryptionProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DecryptionProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DecryptionProfile resources.
 */
export interface DecryptionProfileState {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Must start with alphanumeric char and should contain only alphanemeric, underscore, hyphen, dot or space. String validation regex: `^[A-Za-z0-9]{1}[A-Za-z0-9_\-\.\s]{0,}$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SslForwardProxy param.
     */
    sslForwardProxy?: pulumi.Input<inputs.DecryptionProfileSslForwardProxy>;
    /**
     * The SslInboundProxy param.
     */
    sslInboundProxy?: pulumi.Input<inputs.DecryptionProfileSslInboundProxy>;
    /**
     * The SslNoProxy param.
     */
    sslNoProxy?: pulumi.Input<inputs.DecryptionProfileSslNoProxy>;
    /**
     * The SslProtocolSettings param.
     */
    sslProtocolSettings?: pulumi.Input<inputs.DecryptionProfileSslProtocolSettings>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DecryptionProfile resource.
 */
export interface DecryptionProfileArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Must start with alphanumeric char and should contain only alphanemeric, underscore, hyphen, dot or space. String validation regex: `^[A-Za-z0-9]{1}[A-Za-z0-9_\-\.\s]{0,}$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SslForwardProxy param.
     */
    sslForwardProxy?: pulumi.Input<inputs.DecryptionProfileSslForwardProxy>;
    /**
     * The SslInboundProxy param.
     */
    sslInboundProxy?: pulumi.Input<inputs.DecryptionProfileSslInboundProxy>;
    /**
     * The SslNoProxy param.
     */
    sslNoProxy?: pulumi.Input<inputs.DecryptionProfileSslNoProxy>;
    /**
     * The SslProtocolSettings param.
     */
    sslProtocolSettings?: pulumi.Input<inputs.DecryptionProfileSslProtocolSettings>;
}
