import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAuthenticationProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAuthenticationProfile(args: GetAuthenticationProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetAuthenticationProfileResult>;
/**
 * A collection of arguments for invoking getAuthenticationProfile.
 */
export interface GetAuthenticationProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getAuthenticationProfile.
 */
export interface GetAuthenticationProfileResult {
    /**
     * The AllowList param.
     */
    readonly allowLists: string[];
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Lockout param.
     */
    readonly lockout: outputs.GetAuthenticationProfileLockout;
    /**
     * The Method param.
     */
    readonly method: outputs.GetAuthenticationProfileMethod;
    /**
     * The MultiFactorAuth param.
     */
    readonly multiFactorAuth: outputs.GetAuthenticationProfileMultiFactorAuth;
    /**
     * The Name param.
     */
    readonly name: string;
    /**
     * The SingleSignOn param.
     */
    readonly singleSignOn: outputs.GetAuthenticationProfileSingleSignOn;
    readonly tfid: string;
    /**
     * The UserDomain param. String length must not exceed 63 characters.
     */
    readonly userDomain: string;
    /**
     * The UsernameModifier param. String must be one of these: `"%USERINPUT%"`, `"%USERINPUT%@%USERDOMAIN%"`, `"%USERDOMAIN%\\%USERINPUT%"`.
     */
    readonly usernameModifier: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAuthenticationProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAuthenticationProfileOutput(args: GetAuthenticationProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAuthenticationProfileResult>;
/**
 * A collection of arguments for invoking getAuthenticationProfile.
 */
export interface GetAuthenticationProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
