import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIpsecTunnel({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIpsecTunnel(args: GetIpsecTunnelArgs, opts?: pulumi.InvokeOptions): Promise<GetIpsecTunnelResult>;
/**
 * A collection of arguments for invoking getIpsecTunnel.
 */
export interface GetIpsecTunnelArgs {
    /**
     * The Folder param.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getIpsecTunnel.
 */
export interface GetIpsecTunnelResult {
    /**
     * Enable Anti-Replay check on this tunnel.
     */
    readonly antiReplay: boolean;
    /**
     * The AutoKey param.
     */
    readonly autoKey: outputs.GetIpsecTunnelAutoKey;
    /**
     * Copy IP TOS bits from inner packet to IPSec packet (not recommended). Default: `false`.
     */
    readonly copyTos: boolean;
    /**
     * allow GRE over IPSec. Default: `false`.
     */
    readonly enableGreEncapsulation: boolean;
    /**
     * The Folder param.
     */
    readonly folder?: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    readonly tfid: string;
    /**
     * The TunnelMonitor param.
     */
    readonly tunnelMonitor: outputs.GetIpsecTunnelTunnelMonitor;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIpsecTunnel({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIpsecTunnelOutput(args: GetIpsecTunnelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpsecTunnelResult>;
/**
 * A collection of arguments for invoking getIpsecTunnel.
 */
export interface GetIpsecTunnelOutputArgs {
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
