import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getSnippet({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getSnippet(args: GetSnippetArgs, opts?: pulumi.InvokeOptions): Promise<GetSnippetResult>;
/**
 * A collection of arguments for invoking getSnippet.
 */
export interface GetSnippetArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getSnippet.
 */
export interface GetSnippetResult {
    /**
     * The CreatedIn param.
     */
    readonly createdIn: string;
    /**
     * The Description param.
     */
    readonly description: string;
    /**
     * The DisplayName param.
     */
    readonly displayName: string;
    /**
     * The Folders param.
     */
    readonly folders: outputs.GetSnippetFolder[];
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Labels param.
     */
    readonly labels: string[];
    /**
     * The LastUpdate param.
     */
    readonly lastUpdate: string;
    /**
     * The Name param.
     */
    readonly name: string;
    /**
     * The SharedIn param.
     */
    readonly sharedIn: string;
    readonly tfid: string;
    /**
     * The Type param. String must be one of these: `"predefined"`.
     */
    readonly type: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getSnippet({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getSnippetOutput(args: GetSnippetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSnippetResult>;
/**
 * A collection of arguments for invoking getSnippet.
 */
export interface GetSnippetOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
