import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getUrlAccessProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getUrlAccessProfile(args: GetUrlAccessProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetUrlAccessProfileResult>;
/**
 * A collection of arguments for invoking getUrlAccessProfile.
 */
export interface GetUrlAccessProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getUrlAccessProfile.
 */
export interface GetUrlAccessProfileResult {
    /**
     * The Alerts param.
     */
    readonly alerts: string[];
    /**
     * The Allows param.
     */
    readonly allows: string[];
    /**
     * The Blocks param.
     */
    readonly blocks: string[];
    /**
     * The CloudInlineCat param.
     */
    readonly cloudInlineCat: boolean;
    /**
     * The Continues param.
     */
    readonly continues: string[];
    /**
     * The CredentialEnforcement param.
     */
    readonly credentialEnforcement: outputs.GetUrlAccessProfileCredentialEnforcement;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    readonly description: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The LocalInlineCat param.
     */
    readonly localInlineCat: boolean;
    /**
     * The LogContainerPageOnly param. Default: `true`.
     */
    readonly logContainerPageOnly: boolean;
    /**
     * The LogHttpHdrReferer param. Default: `false`.
     */
    readonly logHttpHdrReferer: boolean;
    /**
     * The LogHttpHdrUserAgent param. Default: `false`.
     */
    readonly logHttpHdrUserAgent: boolean;
    /**
     * The LogHttpHdrXff param. Default: `false`.
     */
    readonly logHttpHdrXff: boolean;
    /**
     * The MlavCategoryExceptions param.
     */
    readonly mlavCategoryExceptions: string[];
    /**
     * The Name param.
     */
    readonly name: string;
    /**
     * The SafeSearchEnforcement param. Default: `false`.
     */
    readonly safeSearchEnforcement: boolean;
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getUrlAccessProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getUrlAccessProfileOutput(args: GetUrlAccessProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUrlAccessProfileResult>;
/**
 * A collection of arguments for invoking getUrlAccessProfile.
 */
export interface GetUrlAccessProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
