import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 */
export declare class IkeGateway extends pulumi.CustomResource {
    /**
     * Get an existing IkeGateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IkeGatewayState, opts?: pulumi.CustomResourceOptions): IkeGateway;
    /**
     * Returns true if the given object is an instance of IkeGateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IkeGateway;
    /**
     * The Authentication param.
     */
    readonly authentication: pulumi.Output<outputs.IkeGatewayAuthentication>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    readonly encryptedValues: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The LocalId param.
     */
    readonly localId: pulumi.Output<outputs.IkeGatewayLocalId | undefined>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The PeerAddress param.
     */
    readonly peerAddress: pulumi.Output<outputs.IkeGatewayPeerAddress>;
    /**
     * The PeerId param.
     */
    readonly peerId: pulumi.Output<outputs.IkeGatewayPeerId | undefined>;
    /**
     * The Protocol param.
     */
    readonly protocol: pulumi.Output<outputs.IkeGatewayProtocol>;
    /**
     * The ProtocolCommon param.
     */
    readonly protocolCommon: pulumi.Output<outputs.IkeGatewayProtocolCommon | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a IkeGateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IkeGatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IkeGateway resources.
 */
export interface IkeGatewayState {
    /**
     * The Authentication param.
     */
    authentication?: pulumi.Input<inputs.IkeGatewayAuthentication>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    encryptedValues?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LocalId param.
     */
    localId?: pulumi.Input<inputs.IkeGatewayLocalId>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The PeerAddress param.
     */
    peerAddress?: pulumi.Input<inputs.IkeGatewayPeerAddress>;
    /**
     * The PeerId param.
     */
    peerId?: pulumi.Input<inputs.IkeGatewayPeerId>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.IkeGatewayProtocol>;
    /**
     * The ProtocolCommon param.
     */
    protocolCommon?: pulumi.Input<inputs.IkeGatewayProtocolCommon>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a IkeGateway resource.
 */
export interface IkeGatewayArgs {
    /**
     * The Authentication param.
     */
    authentication: pulumi.Input<inputs.IkeGatewayAuthentication>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LocalId param.
     */
    localId?: pulumi.Input<inputs.IkeGatewayLocalId>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The PeerAddress param.
     */
    peerAddress: pulumi.Input<inputs.IkeGatewayPeerAddress>;
    /**
     * The PeerId param.
     */
    peerId?: pulumi.Input<inputs.IkeGatewayPeerId>;
    /**
     * The Protocol param.
     */
    protocol: pulumi.Input<inputs.IkeGatewayProtocol>;
    /**
     * The ProtocolCommon param.
     */
    protocolCommon?: pulumi.Input<inputs.IkeGatewayProtocolCommon>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
