import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.LdapServerProfile("example", {});
 * ```
 */
export declare class LdapServerProfile extends pulumi.CustomResource {
    /**
     * Get an existing LdapServerProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LdapServerProfileState, opts?: pulumi.CustomResourceOptions): LdapServerProfile;
    /**
     * Returns true if the given object is an instance of LdapServerProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LdapServerProfile;
    /**
     * The Base param. String length must not exceed 255 characters.
     */
    readonly base: pulumi.Output<string | undefined>;
    /**
     * The BindDn param. String length must not exceed 255 characters.
     */
    readonly bindDn: pulumi.Output<string | undefined>;
    /**
     * The BindPassword param. String length must not exceed 121 characters.
     */
    readonly bindPassword: pulumi.Output<string | undefined>;
    /**
     * The BindTimelimit param.
     */
    readonly bindTimelimit: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The LdapType param. String must be one of these: `"active-directory"`, `"e-directory"`, `"sun"`, `"other"`.
     */
    readonly ldapType: pulumi.Output<string | undefined>;
    /**
     * The RetryInterval param.
     */
    readonly retryInterval: pulumi.Output<number | undefined>;
    /**
     * The Servers param.
     */
    readonly servers: pulumi.Output<outputs.LdapServerProfileServer[]>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Ssl param.
     */
    readonly ssl: pulumi.Output<boolean | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Timelimit param.
     */
    readonly timelimit: pulumi.Output<number | undefined>;
    /**
     * The VerifyServerCertificate param.
     */
    readonly verifyServerCertificate: pulumi.Output<boolean | undefined>;
    /**
     * Create a LdapServerProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LdapServerProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LdapServerProfile resources.
 */
export interface LdapServerProfileState {
    /**
     * The Base param. String length must not exceed 255 characters.
     */
    base?: pulumi.Input<string>;
    /**
     * The BindDn param. String length must not exceed 255 characters.
     */
    bindDn?: pulumi.Input<string>;
    /**
     * The BindPassword param. String length must not exceed 121 characters.
     */
    bindPassword?: pulumi.Input<string>;
    /**
     * The BindTimelimit param.
     */
    bindTimelimit?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LdapType param. String must be one of these: `"active-directory"`, `"e-directory"`, `"sun"`, `"other"`.
     */
    ldapType?: pulumi.Input<string>;
    /**
     * The RetryInterval param.
     */
    retryInterval?: pulumi.Input<number>;
    /**
     * The Servers param.
     */
    servers?: pulumi.Input<pulumi.Input<inputs.LdapServerProfileServer>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Ssl param.
     */
    ssl?: pulumi.Input<boolean>;
    tfid?: pulumi.Input<string>;
    /**
     * The Timelimit param.
     */
    timelimit?: pulumi.Input<number>;
    /**
     * The VerifyServerCertificate param.
     */
    verifyServerCertificate?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a LdapServerProfile resource.
 */
export interface LdapServerProfileArgs {
    /**
     * The Base param. String length must not exceed 255 characters.
     */
    base?: pulumi.Input<string>;
    /**
     * The BindDn param. String length must not exceed 255 characters.
     */
    bindDn?: pulumi.Input<string>;
    /**
     * The BindPassword param. String length must not exceed 121 characters.
     */
    bindPassword?: pulumi.Input<string>;
    /**
     * The BindTimelimit param.
     */
    bindTimelimit?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LdapType param. String must be one of these: `"active-directory"`, `"e-directory"`, `"sun"`, `"other"`.
     */
    ldapType?: pulumi.Input<string>;
    /**
     * The RetryInterval param.
     */
    retryInterval?: pulumi.Input<number>;
    /**
     * The Servers param.
     */
    servers: pulumi.Input<pulumi.Input<inputs.LdapServerProfileServer>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Ssl param.
     */
    ssl?: pulumi.Input<boolean>;
    /**
     * The Timelimit param.
     */
    timelimit?: pulumi.Input<number>;
    /**
     * The VerifyServerCertificate param.
     */
    verifyServerCertificate?: pulumi.Input<boolean>;
}
