import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 */
export declare class NatRule extends pulumi.CustomResource {
    /**
     * Get an existing NatRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: NatRuleState, opts?: pulumi.CustomResourceOptions): NatRule;
    /**
     * Returns true if the given object is an instance of NatRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NatRule;
    /**
     * The ActiveActiveDeviceBinding param. String must be one of these: `"primary"`, `"both"`, `"0"`, `"1"`.
     */
    readonly activeActiveDeviceBinding: pulumi.Output<string | undefined>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Static destination translation parameter.
     */
    readonly destinationTranslation: pulumi.Output<outputs.NatRuleDestinationTranslation | undefined>;
    /**
     * The destination address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    readonly destinations: pulumi.Output<string[]>;
    /**
     * The device in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Disabled param.
     */
    readonly disabled: pulumi.Output<boolean | undefined>;
    /**
     * Dynamic destination translation parameter.
     */
    readonly dynamicDestinationTranslation: pulumi.Output<outputs.NatRuleDynamicDestinationTranslation | undefined>;
    /**
     * The folder in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The source security zone(s). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    readonly froms: pulumi.Output<string[]>;
    /**
     * The GroupTag param.
     */
    readonly groupTag: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NatType param. String must be one of these: `"ipv4"`, `"nat64"`, `"nptv6"`.
     */
    readonly natType: pulumi.Output<string | undefined>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The Service param.
     */
    readonly service: pulumi.Output<string>;
    /**
     * The snippet in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The SourceTranslation param.
     */
    readonly sourceTranslation: pulumi.Output<outputs.NatRuleSourceTranslation | undefined>;
    /**
     * The source address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    readonly sources: pulumi.Output<string[]>;
    /**
     * The Tags param.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * The Target param.
     */
    readonly target: pulumi.Output<outputs.NatRuleTarget | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The ToInterface param. String must be one of these: `"any"`.
     */
    readonly toInterface: pulumi.Output<string | undefined>;
    /**
     * The destination security zone(s).
     */
    readonly tos: pulumi.Output<string[]>;
    /**
     * Create a NatRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NatRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering NatRule resources.
 */
export interface NatRuleState {
    /**
     * The ActiveActiveDeviceBinding param. String must be one of these: `"primary"`, `"both"`, `"0"`, `"1"`.
     */
    activeActiveDeviceBinding?: pulumi.Input<string>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * Static destination translation parameter.
     */
    destinationTranslation?: pulumi.Input<inputs.NatRuleDestinationTranslation>;
    /**
     * The destination address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The device in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Dynamic destination translation parameter.
     */
    dynamicDestinationTranslation?: pulumi.Input<inputs.NatRuleDynamicDestinationTranslation>;
    /**
     * The folder in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The source security zone(s). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NatType param. String must be one of these: `"ipv4"`, `"nat64"`, `"nptv6"`.
     */
    natType?: pulumi.Input<string>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Service param.
     */
    service?: pulumi.Input<string>;
    /**
     * The snippet in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceTranslation param.
     */
    sourceTranslation?: pulumi.Input<inputs.NatRuleSourceTranslation>;
    /**
     * The source address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Target param.
     */
    target?: pulumi.Input<inputs.NatRuleTarget>;
    tfid?: pulumi.Input<string>;
    /**
     * The ToInterface param. String must be one of these: `"any"`.
     */
    toInterface?: pulumi.Input<string>;
    /**
     * The destination security zone(s).
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a NatRule resource.
 */
export interface NatRuleArgs {
    /**
     * The ActiveActiveDeviceBinding param. String must be one of these: `"primary"`, `"both"`, `"0"`, `"1"`.
     */
    activeActiveDeviceBinding?: pulumi.Input<string>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * Static destination translation parameter.
     */
    destinationTranslation?: pulumi.Input<inputs.NatRuleDestinationTranslation>;
    /**
     * The destination address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    destinations: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The device in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Dynamic destination translation parameter.
     */
    dynamicDestinationTranslation?: pulumi.Input<inputs.NatRuleDynamicDestinationTranslation>;
    /**
     * The folder in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The source security zone(s). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    froms: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NatType param. String must be one of these: `"ipv4"`, `"nat64"`, `"nptv6"`.
     */
    natType?: pulumi.Input<string>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Service param.
     */
    service: pulumi.Input<string>;
    /**
     * The snippet in which the resource is defined. String length must not exceed 64 characters. String validation regex: `^[a-zA-Z\d-_\. ]+$`.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceTranslation param.
     */
    sourceTranslation?: pulumi.Input<inputs.NatRuleSourceTranslation>;
    /**
     * The source address(es). Individual elements in this list are subject to additional validation. String must be one of these: `"any"`.
     */
    sources: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Target param.
     */
    target?: pulumi.Input<inputs.NatRuleTarget>;
    /**
     * The ToInterface param. String must be one of these: `"any"`.
     */
    toInterface?: pulumi.Input<string>;
    /**
     * The destination security zone(s).
     */
    tos: pulumi.Input<pulumi.Input<string>[]>;
}
