import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.ProfileGroup("example", {});
 * ```
 */
export declare class ProfileGroup extends pulumi.CustomResource {
    /**
     * Get an existing ProfileGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ProfileGroupState, opts?: pulumi.CustomResourceOptions): ProfileGroup;
    /**
     * Returns true if the given object is an instance of ProfileGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProfileGroup;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The DnsSecurities param.
     */
    readonly dnsSecurities: pulumi.Output<string[] | undefined>;
    /**
     * The FileBlockings param.
     */
    readonly fileBlockings: pulumi.Output<string[] | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The SaasSecurities param.
     */
    readonly saasSecurities: pulumi.Output<string[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Spywares param.
     */
    readonly spywares: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The UrlFilterings param.
     */
    readonly urlFilterings: pulumi.Output<string[] | undefined>;
    /**
     * The VirusAndWildfireAnalyses param.
     */
    readonly virusAndWildfireAnalyses: pulumi.Output<string[] | undefined>;
    /**
     * The Vulnerabilities param.
     */
    readonly vulnerabilities: pulumi.Output<string[] | undefined>;
    /**
     * Create a ProfileGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProfileGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ProfileGroup resources.
 */
export interface ProfileGroupState {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DnsSecurities param.
     */
    dnsSecurities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The FileBlockings param.
     */
    fileBlockings?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SaasSecurities param.
     */
    saasSecurities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Spywares param.
     */
    spywares?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The UrlFilterings param.
     */
    urlFilterings?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The VirusAndWildfireAnalyses param.
     */
    virusAndWildfireAnalyses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Vulnerabilities param.
     */
    vulnerabilities?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a ProfileGroup resource.
 */
export interface ProfileGroupArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DnsSecurities param.
     */
    dnsSecurities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The FileBlockings param.
     */
    fileBlockings?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SaasSecurities param.
     */
    saasSecurities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Spywares param.
     */
    spywares?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The UrlFilterings param.
     */
    urlFilterings?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The VirusAndWildfireAnalyses param.
     */
    virusAndWildfireAnalyses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Vulnerabilities param.
     */
    vulnerabilities?: pulumi.Input<pulumi.Input<string>[]>;
}
