import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 */
export declare class RadiusServerProfile extends pulumi.CustomResource {
    /**
     * Get an existing RadiusServerProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RadiusServerProfileState, opts?: pulumi.CustomResourceOptions): RadiusServerProfile;
    /**
     * Returns true if the given object is an instance of RadiusServerProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RadiusServerProfile;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    readonly encryptedValues: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Protocol param.
     */
    readonly protocol: pulumi.Output<outputs.RadiusServerProfileProtocol | undefined>;
    /**
     * The Retries param. Value must be between 1 and 5.
     */
    readonly retries: pulumi.Output<number | undefined>;
    /**
     * The Servers param.
     */
    readonly servers: pulumi.Output<outputs.RadiusServerProfileServer[]>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Timeout param. Value must be between 1 and 120.
     */
    readonly timeout: pulumi.Output<number | undefined>;
    /**
     * Create a RadiusServerProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RadiusServerProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RadiusServerProfile resources.
 */
export interface RadiusServerProfileState {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    encryptedValues?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.RadiusServerProfileProtocol>;
    /**
     * The Retries param. Value must be between 1 and 5.
     */
    retries?: pulumi.Input<number>;
    /**
     * The Servers param.
     */
    servers?: pulumi.Input<pulumi.Input<inputs.RadiusServerProfileServer>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The Timeout param. Value must be between 1 and 120.
     */
    timeout?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a RadiusServerProfile resource.
 */
export interface RadiusServerProfileArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.RadiusServerProfileProtocol>;
    /**
     * The Retries param. Value must be between 1 and 5.
     */
    retries?: pulumi.Input<number>;
    /**
     * The Servers param.
     */
    servers: pulumi.Input<pulumi.Input<inputs.RadiusServerProfileServer>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Timeout param. Value must be between 1 and 120.
     */
    timeout?: pulumi.Input<number>;
}
