import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.SecurityRule("example", {});
 * ```
 */
export declare class SecurityRule extends pulumi.CustomResource {
    /**
     * Get an existing SecurityRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SecurityRuleState, opts?: pulumi.CustomResourceOptions): SecurityRule;
    /**
     * Returns true if the given object is an instance of SecurityRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityRule;
    /**
     * The action to be taken when the rule is matched. String must be one of these: `"allow"`, `"deny"`, `"drop"`, `"reset-client"`, `"reset-server"`, `"reset-both"`.
     */
    readonly action: pulumi.Output<string>;
    /**
     * The application(s) being accessed.
     */
    readonly applications: pulumi.Output<string[]>;
    /**
     * The URL categories being accessed.
     */
    readonly categories: pulumi.Output<string[]>;
    /**
     * The description of the security rule.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The destination Host Integrity Profile(s).
     */
    readonly destinationHips: pulumi.Output<string[] | undefined>;
    /**
     * The destination address(es).
     */
    readonly destinations: pulumi.Output<string[]>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The state of the security rule. Default: `false`.
     */
    readonly disabled: pulumi.Output<boolean>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The source security zone(s).
     */
    readonly froms: pulumi.Output<string[]>;
    /**
     * The external log forwarding profile.
     */
    readonly logSetting: pulumi.Output<string | undefined>;
    /**
     * The name of the security rule.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Negate the destination addresses(es). Default: `false`.
     */
    readonly negateDestination: pulumi.Output<boolean>;
    /**
     * Negate the source address(es). Default: `false`.
     */
    readonly negateSource: pulumi.Output<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The security profile object.
     */
    readonly profileSetting: pulumi.Output<outputs.SecurityRuleProfileSetting | undefined>;
    /**
     * The service(s) being accessed.
     */
    readonly services: pulumi.Output<string[]>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The source Host Integrity Profile(s).
     */
    readonly sourceHips: pulumi.Output<string[] | undefined>;
    /**
     * The source user(s) or group(s).
     */
    readonly sourceUsers: pulumi.Output<string[]>;
    /**
     * The source address(es).
     */
    readonly sources: pulumi.Output<string[]>;
    /**
     * The tags associated with the security rule.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The destination security zone(s).
     */
    readonly tos: pulumi.Output<string[]>;
    /**
     * Create a SecurityRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SecurityRule resources.
 */
export interface SecurityRuleState {
    /**
     * The action to be taken when the rule is matched. String must be one of these: `"allow"`, `"deny"`, `"drop"`, `"reset-client"`, `"reset-server"`, `"reset-both"`.
     */
    action?: pulumi.Input<string>;
    /**
     * The application(s) being accessed.
     */
    applications?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The URL categories being accessed.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the security rule.
     */
    description?: pulumi.Input<string>;
    /**
     * The destination Host Integrity Profile(s).
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The destination address(es).
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The state of the security rule. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The source security zone(s).
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The external log forwarding profile.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The name of the security rule.
     */
    name?: pulumi.Input<string>;
    /**
     * Negate the destination addresses(es). Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * Negate the source address(es). Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The security profile object.
     */
    profileSetting?: pulumi.Input<inputs.SecurityRuleProfileSetting>;
    /**
     * The service(s) being accessed.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The source Host Integrity Profile(s).
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The source user(s) or group(s).
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The source address(es).
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags associated with the security rule.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The destination security zone(s).
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a SecurityRule resource.
 */
export interface SecurityRuleArgs {
    /**
     * The action to be taken when the rule is matched. String must be one of these: `"allow"`, `"deny"`, `"drop"`, `"reset-client"`, `"reset-server"`, `"reset-both"`.
     */
    action: pulumi.Input<string>;
    /**
     * The application(s) being accessed.
     */
    applications: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The URL categories being accessed.
     */
    categories: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the security rule.
     */
    description?: pulumi.Input<string>;
    /**
     * The destination Host Integrity Profile(s).
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The destination address(es).
     */
    destinations: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The state of the security rule. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The source security zone(s).
     */
    froms: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The external log forwarding profile.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The name of the security rule.
     */
    name?: pulumi.Input<string>;
    /**
     * Negate the destination addresses(es). Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * Negate the source address(es). Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The security profile object.
     */
    profileSetting?: pulumi.Input<inputs.SecurityRuleProfileSetting>;
    /**
     * The service(s) being accessed.
     */
    services: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The source Host Integrity Profile(s).
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The source user(s) or group(s).
     */
    sourceUsers: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The source address(es).
     */
    sources: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags associated with the security rule.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The destination security zone(s).
     */
    tos: pulumi.Input<pulumi.Input<string>[]>;
}
