import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.ServiceConnection("example", {});
 * ```
 */
export declare class ServiceConnection extends pulumi.CustomResource {
    /**
     * Get an existing ServiceConnection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceConnectionState, opts?: pulumi.CustomResourceOptions): ServiceConnection;
    /**
     * Returns true if the given object is an instance of ServiceConnection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceConnection;
    /**
     * The BackupSC param.
     */
    readonly backupSC: pulumi.Output<string | undefined>;
    /**
     * The BgpPeer param.
     */
    readonly bgpPeer: pulumi.Output<outputs.ServiceConnectionBgpPeer | undefined>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    readonly encryptedValues: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    readonly folder: pulumi.Output<string>;
    /**
     * The IpsecTunnel param.
     */
    readonly ipsecTunnel: pulumi.Output<string>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NatPool param.
     */
    readonly natPool: pulumi.Output<string | undefined>;
    /**
     * The NoExportCommunity param. String must be one of these: `"Disabled"`, `"Enabled-In"`, `"Enabled-Out"`, `"Enabled-Both"`.
     */
    readonly noExportCommunity: pulumi.Output<string | undefined>;
    /**
     * The OnboardingType param. String must be one of these: `"classic"`. Default: `"classic"`.
     */
    readonly onboardingType: pulumi.Output<string>;
    /**
     * The Protocol param.
     */
    readonly protocol: pulumi.Output<outputs.ServiceConnectionProtocol | undefined>;
    /**
     * The Qos param.
     */
    readonly qos: pulumi.Output<outputs.ServiceConnectionQos | undefined>;
    /**
     * The Region param.
     */
    readonly region: pulumi.Output<string>;
    /**
     * The SecondaryIpsecTunnel param.
     */
    readonly secondaryIpsecTunnel: pulumi.Output<string | undefined>;
    /**
     * The SourceNat param.
     */
    readonly sourceNat: pulumi.Output<boolean | undefined>;
    /**
     * The Subnets param.
     */
    readonly subnets: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a ServiceConnection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceConnection resources.
 */
export interface ServiceConnectionState {
    /**
     * The BackupSC param.
     */
    backupSC?: pulumi.Input<string>;
    /**
     * The BgpPeer param.
     */
    bgpPeer?: pulumi.Input<inputs.ServiceConnectionBgpPeer>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    encryptedValues?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The IpsecTunnel param.
     */
    ipsecTunnel?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NatPool param.
     */
    natPool?: pulumi.Input<string>;
    /**
     * The NoExportCommunity param. String must be one of these: `"Disabled"`, `"Enabled-In"`, `"Enabled-Out"`, `"Enabled-Both"`.
     */
    noExportCommunity?: pulumi.Input<string>;
    /**
     * The OnboardingType param. String must be one of these: `"classic"`. Default: `"classic"`.
     */
    onboardingType?: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.ServiceConnectionProtocol>;
    /**
     * The Qos param.
     */
    qos?: pulumi.Input<inputs.ServiceConnectionQos>;
    /**
     * The Region param.
     */
    region?: pulumi.Input<string>;
    /**
     * The SecondaryIpsecTunnel param.
     */
    secondaryIpsecTunnel?: pulumi.Input<string>;
    /**
     * The SourceNat param.
     */
    sourceNat?: pulumi.Input<boolean>;
    /**
     * The Subnets param.
     */
    subnets?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ServiceConnection resource.
 */
export interface ServiceConnectionArgs {
    /**
     * The BackupSC param.
     */
    backupSC?: pulumi.Input<string>;
    /**
     * The BgpPeer param.
     */
    bgpPeer?: pulumi.Input<inputs.ServiceConnectionBgpPeer>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The IpsecTunnel param.
     */
    ipsecTunnel: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NatPool param.
     */
    natPool?: pulumi.Input<string>;
    /**
     * The NoExportCommunity param. String must be one of these: `"Disabled"`, `"Enabled-In"`, `"Enabled-Out"`, `"Enabled-Both"`.
     */
    noExportCommunity?: pulumi.Input<string>;
    /**
     * The OnboardingType param. String must be one of these: `"classic"`. Default: `"classic"`.
     */
    onboardingType?: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.ServiceConnectionProtocol>;
    /**
     * The Qos param.
     */
    qos?: pulumi.Input<inputs.ServiceConnectionQos>;
    /**
     * The Region param.
     */
    region: pulumi.Input<string>;
    /**
     * The SecondaryIpsecTunnel param.
     */
    secondaryIpsecTunnel?: pulumi.Input<string>;
    /**
     * The SourceNat param.
     */
    sourceNat?: pulumi.Input<boolean>;
    /**
     * The Subnets param.
     */
    subnets?: pulumi.Input<pulumi.Input<string>[]>;
}
