import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.TlsServiceProfile("example", {folder: "Shared"});
 * ```
 */
export declare class TlsServiceProfile extends pulumi.CustomResource {
    /**
     * Get an existing TlsServiceProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TlsServiceProfileState, opts?: pulumi.CustomResourceOptions): TlsServiceProfile;
    /**
     * Returns true if the given object is an instance of TlsServiceProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TlsServiceProfile;
    /**
     * SSL certificate file name. String length must not exceed 255 characters.
     */
    readonly certificate: pulumi.Output<string>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * SSL TLS Service Profile name, value is muCustomDomainSSLProfile when it is used on mobile-agent infra settings. String length must not exceed 127 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ProtocolSettings param.
     */
    readonly protocolSettings: pulumi.Output<outputs.TlsServiceProfileProtocolSettings>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a TlsServiceProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TlsServiceProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TlsServiceProfile resources.
 */
export interface TlsServiceProfileState {
    /**
     * SSL certificate file name. String length must not exceed 255 characters.
     */
    certificate?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * SSL TLS Service Profile name, value is muCustomDomainSSLProfile when it is used on mobile-agent infra settings. String length must not exceed 127 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The ProtocolSettings param.
     */
    protocolSettings?: pulumi.Input<inputs.TlsServiceProfileProtocolSettings>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TlsServiceProfile resource.
 */
export interface TlsServiceProfileArgs {
    /**
     * SSL certificate file name. String length must not exceed 255 characters.
     */
    certificate: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * SSL TLS Service Profile name, value is muCustomDomainSSLProfile when it is used on mobile-agent infra settings. String length must not exceed 127 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The ProtocolSettings param.
     */
    protocolSettings: pulumi.Input<inputs.TlsServiceProfileProtocolSettings>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
