import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.UrlAccessProfile("example", {folder: "Shared"});
 * ```
 */
export declare class UrlAccessProfile extends pulumi.CustomResource {
    /**
     * Get an existing UrlAccessProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UrlAccessProfileState, opts?: pulumi.CustomResourceOptions): UrlAccessProfile;
    /**
     * Returns true if the given object is an instance of UrlAccessProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UrlAccessProfile;
    /**
     * The Alerts param.
     */
    readonly alerts: pulumi.Output<string[] | undefined>;
    /**
     * The Allows param.
     */
    readonly allows: pulumi.Output<string[] | undefined>;
    /**
     * The Blocks param.
     */
    readonly blocks: pulumi.Output<string[] | undefined>;
    /**
     * The CloudInlineCat param.
     */
    readonly cloudInlineCat: pulumi.Output<boolean | undefined>;
    /**
     * The Continues param.
     */
    readonly continues: pulumi.Output<string[] | undefined>;
    /**
     * The CredentialEnforcement param.
     */
    readonly credentialEnforcement: pulumi.Output<outputs.UrlAccessProfileCredentialEnforcement | undefined>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The LocalInlineCat param.
     */
    readonly localInlineCat: pulumi.Output<boolean | undefined>;
    /**
     * The LogContainerPageOnly param. Default: `true`.
     */
    readonly logContainerPageOnly: pulumi.Output<boolean>;
    /**
     * The LogHttpHdrReferer param. Default: `false`.
     */
    readonly logHttpHdrReferer: pulumi.Output<boolean>;
    /**
     * The LogHttpHdrUserAgent param. Default: `false`.
     */
    readonly logHttpHdrUserAgent: pulumi.Output<boolean>;
    /**
     * The LogHttpHdrXff param. Default: `false`.
     */
    readonly logHttpHdrXff: pulumi.Output<boolean>;
    /**
     * The MlavCategoryExceptions param.
     */
    readonly mlavCategoryExceptions: pulumi.Output<string[] | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The SafeSearchEnforcement param. Default: `false`.
     */
    readonly safeSearchEnforcement: pulumi.Output<boolean>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a UrlAccessProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: UrlAccessProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UrlAccessProfile resources.
 */
export interface UrlAccessProfileState {
    /**
     * The Alerts param.
     */
    alerts?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Allows param.
     */
    allows?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Blocks param.
     */
    blocks?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The CloudInlineCat param.
     */
    cloudInlineCat?: pulumi.Input<boolean>;
    /**
     * The Continues param.
     */
    continues?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The CredentialEnforcement param.
     */
    credentialEnforcement?: pulumi.Input<inputs.UrlAccessProfileCredentialEnforcement>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LocalInlineCat param.
     */
    localInlineCat?: pulumi.Input<boolean>;
    /**
     * The LogContainerPageOnly param. Default: `true`.
     */
    logContainerPageOnly?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrReferer param. Default: `false`.
     */
    logHttpHdrReferer?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrUserAgent param. Default: `false`.
     */
    logHttpHdrUserAgent?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrXff param. Default: `false`.
     */
    logHttpHdrXff?: pulumi.Input<boolean>;
    /**
     * The MlavCategoryExceptions param.
     */
    mlavCategoryExceptions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SafeSearchEnforcement param. Default: `false`.
     */
    safeSearchEnforcement?: pulumi.Input<boolean>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UrlAccessProfile resource.
 */
export interface UrlAccessProfileArgs {
    /**
     * The Alerts param.
     */
    alerts?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Allows param.
     */
    allows?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Blocks param.
     */
    blocks?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The CloudInlineCat param.
     */
    cloudInlineCat?: pulumi.Input<boolean>;
    /**
     * The Continues param.
     */
    continues?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The CredentialEnforcement param.
     */
    credentialEnforcement?: pulumi.Input<inputs.UrlAccessProfileCredentialEnforcement>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The LocalInlineCat param.
     */
    localInlineCat?: pulumi.Input<boolean>;
    /**
     * The LogContainerPageOnly param. Default: `true`.
     */
    logContainerPageOnly?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrReferer param. Default: `false`.
     */
    logHttpHdrReferer?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrUserAgent param. Default: `false`.
     */
    logHttpHdrUserAgent?: pulumi.Input<boolean>;
    /**
     * The LogHttpHdrXff param. Default: `false`.
     */
    logHttpHdrXff?: pulumi.Input<boolean>;
    /**
     * The MlavCategoryExceptions param.
     */
    mlavCategoryExceptions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SafeSearchEnforcement param. Default: `false`.
     */
    safeSearchEnforcement?: pulumi.Input<boolean>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
