import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.UrlCategory("example", {folder: "Shared"});
 * ```
 */
export declare class UrlCategory extends pulumi.CustomResource {
    /**
     * Get an existing UrlCategory resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UrlCategoryState, opts?: pulumi.CustomResourceOptions): UrlCategory;
    /**
     * Returns true if the given object is an instance of UrlCategory.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UrlCategory;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The List param.
     */
    readonly lists: pulumi.Output<string[] | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Type param. String must be one of these: `"URL List"`, `"Category Match"`. Default: `"URL List"`.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a UrlCategory resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: UrlCategoryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UrlCategory resources.
 */
export interface UrlCategoryState {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The List param.
     */
    lists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The Type param. String must be one of these: `"URL List"`, `"Category Match"`. Default: `"URL List"`.
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UrlCategory resource.
 */
export interface UrlCategoryArgs {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The List param.
     */
    lists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Type param. String must be one of these: `"URL List"`, `"Category Match"`. Default: `"URL List"`.
     */
    type?: pulumi.Input<string>;
}
