import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.VulnerabilityProtectionProfile("example", {folder: "Shared"});
 * ```
 */
export declare class VulnerabilityProtectionProfile extends pulumi.CustomResource {
    /**
     * Get an existing VulnerabilityProtectionProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: VulnerabilityProtectionProfileState, opts?: pulumi.CustomResourceOptions): VulnerabilityProtectionProfile;
    /**
     * Returns true if the given object is an instance of VulnerabilityProtectionProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VulnerabilityProtectionProfile;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Rules param.
     */
    readonly rules: pulumi.Output<outputs.VulnerabilityProtectionProfileRule[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The ThreatExceptions param.
     */
    readonly threatExceptions: pulumi.Output<outputs.VulnerabilityProtectionProfileThreatException[] | undefined>;
    /**
     * Create a VulnerabilityProtectionProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: VulnerabilityProtectionProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering VulnerabilityProtectionProfile resources.
 */
export interface VulnerabilityProtectionProfileState {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionProfileThreatException>[]>;
}
/**
 * The set of arguments for constructing a VulnerabilityProtectionProfile resource.
 */
export interface VulnerabilityProtectionProfileArgs {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionProfileThreatException>[]>;
}
